#  Common Evaluation metrics graph plot for Regression 

## Description
Python implementations for comparing different Regression Models and Plotting with their most common evaluation metrics.

The purpose of this package is to help users plot the graph at ease with different widely used metrics for regression model evaluation for comparing them at a glance 

<p align="center">
    <img src="https://github.com/ajayarunachalam/RegressorMetricGraphPlot/blob/main/regressormetricgraphplot/example_plot.png" width="640"\>
</p>
<p align="center">
    Figure: Model evaluation plot with widely used metrics 
</p>


## Table of Contents
- [Compare Regression Model Metrics Plot](#regressormetricgraphplot)
  * [Installation](#installation)
  * [Examples](#examples)
    + [Demo](#Usage))
  * [Contact](#contact)

## Installation 
    $ pip install regressormetricgraphplot

         OR

    $ git clone https://github.com/ajayarunachalam/RegressorMetricGraphPlot
    $ cd RegressorMetricGraphPlot
    $ python setup.py install

## Notebook
    !git clone https://github.com/ajayarunachalam/RegressorMetricGraphPlot.git
    cd RegressorMetricGraphPlot/

    Just replace the line 'from CompareModels import *' with 'from regressioncomparemetricplot import CompareModels' 
Follow the rest as demonstrated in the demo example [here] -- (https://github.com/ajayarunachalam/RegressorMetricGraphPlot/blob/main/regressormetricgraphplot/demo.ipynb) 

## Installation with Anaconda

If you installed your Python with Anacoda you can run the following commands to get started:
```bash

# Clone the repository 
git clone https://github.com/ajayarunachalam/RegressorMetricGraphPlot.git
cd RegressorMetricGraphPlot
# Create new conda environment with Python 3.6
conda create --new your-env-name python=3.6
# Activate the environment
conda activate your-env-name
# Install conda dependencies
conda install --yes --file conda_requirements.txt
# Instal pip dependencies
pip install requirements.txt
```



## Examples
Navigate to the demo example in a form of iPython notebooks: -- [here](https://github.com/ajayarunachalam/RegressorMetricGraphPlot/blob/main/regressormetricgraphplot/demo.ipynb)


### Demo
     * demo.ipynb 

## Contact
If there's some implementation you would like to see here or add in some examples feel free to do so. You can reach me at [email](mailto:ajay.arunachalam08@gmail.com)
